==> ameba-1.23.tar.bz2: ameba-1.23/conditions.h <==
#ifndef _CONDITS_H
#define _CONDITS_H

#include <errlog.h>
#include <configs.h>
#include <astrotime.h>
#include <client_handler.h>
#include <coordinates.h>

struct SV_PAR {
    std::string cfgfile;
    bool test_mode;
    bool man_mode;
    double start_time;
    double night_time;
    double watch_time;
    double twill_time;
    double final_time;
};

struct Detect {
    int errcount;
    double value;
    double low_limit;
    double high_limit;
    double last_event;
    double hold_time;
    bool   flag;
    Detect() : errcount(0), value(0), low_limit(1), high_limit(1), last_event(-1800), hold_time(1800), flag(false) {}
};

class Condition {
    static AstroDateTime ut_con;
    Config acfg;
    SolarSys sun;
    ClientSocket::AddrType meteoIP;
    ClientSocket::AddrType skyIP;
    std::auto_ptr<ClientHandler> meteo;
    std::auto_ptr<ClientHandler> sky;
    Detect wind;
    Detect sky_sens;
    Detect supp;
    double civil_twil;
    double astro_twil;
    unsigned int sens_period;
    unsigned int error_pause;
public:
    static SV_PAR cmd;
    static bool terminate;
    Condition();
//    ~Condition(){ delete ASM; }
    ~Condition(){}
    bool bad();
    bool good();
//    static double loc_time();
    static double utc();
    double restart_time();
    void wait_conditions();
    bool night_time();
    bool evening_time();
    bool morning_time();
private:
    std::string status();
    bool wind_watch();
    bool sky_watch();
    bool supp_watch();
//    double sunset( double );
//    double sunrise( double );
    static double ltc();
};

#endif

==> ameba-1.25.tar.bz2: ameba-1.25/conditions.h <==
#ifndef _CONDITS_H
#define _CONDITS_H

#include <errlog.h>
#include <configs.h>
#include <astrotime.h>
#include <client_handler.h>
#include <coordinates.h>

struct SV_PAR {
    std::string cfgfile;
    bool test_mode;
    bool man_mode;
    double start_time;
    double night_time;
    double watch_time;
    double twill_time;
    double final_time;
};

struct Detect {
    int errcount;
    double value;
    double close_limit;
    double low_limit;
    double high_limit;
    double last_event;
    double hold_time;
    bool   flag;
    Detect() : errcount(0), value(0), close_limit(1), low_limit(1), high_limit(1), last_event(-1800), hold_time(1800), flag(false) {}
};

class Condition {
    static AstroDateTime ut_con;
    Config acfg;
    SolarSys sun;
    ClientSocket::AddrType meteoIP;
    ClientSocket::AddrType skyIP;
    std::auto_ptr<ClientHandler> meteo;
    std::auto_ptr<ClientHandler> sky;
    Detect wind;
    Detect sky_sens;
    Detect supp;
    double civil_twil;
    double astro_twil;
    unsigned int sens_period;
    unsigned int error_pause;
public:
    static SV_PAR cmd;
    static bool terminate;
    Condition();
//    ~Condition(){ delete ASM; }
    ~Condition(){}
    bool bad();
    bool good();
//    static double loc_time();
    static double utc();
    double restart_time();
    void wait_conditions();
    bool night_time();
    bool evening_time();
    bool morning_time();
private:
    std::string status();
    bool wind_watch();
    bool sky_watch();
    bool supp_watch();
//    double sunset( double );
//    double sunrise( double );
    static double ltc();
};

#endif
